@@ -1,18 +1,26 @@
-__version__ = "2.0.2"
+__version__ = "2.1.0"
 
+from .base import BaseDeviceClass
+from .binary_sensor.device_class import BinarySensorDeviceClass
 from .data import SensorData, SensorDeviceInfo, SensorUpdate
 from .description import SensorDescription
 from .device import DeviceKey
 from .device_class import DeviceClass
 from .library import SensorLibrary
+from .sensor.device_class import SensorDeviceClass
 from .units import Units
-from .value import SensorValue
+from .value import BaseValue, BinarySensorValue, SensorValue
 
 __all__ = [
+    "BaseDeviceClass",
+    "BaseValue",
+    "BinarySensorValue",
+    "BinarySensorDeviceClass",
     "DeviceClass",
     "DeviceKey",
     "SensorData",
     "SensorDescription",
+    "SensorDeviceClass",
     "SensorDeviceInfo",
     "SensorLibrary",
     "SensorUpdate",
