@@ -6,11 +6,16 @@ from datetime import date, datetime
 from decimal import Decimal
 from typing import Any
 
-from .description import BaseSensorDescription, SensorDescription
+from .binary_sensor.device_class import BinarySensorDeviceClass
+from .description import (
+    BaseSensorDescription,
+    BinarySensorDescription,
+    SensorDescription,
+)
 from .device import DeviceKey
-from .device_class import DeviceClass
+from .sensor.device_class import SensorDeviceClass
 from .units import Units
-from .value import SensorValue
+from .value import BinarySensorValue, SensorValue
 
 
 @dataclasses.dataclass(frozen=False)
@@ -30,6 +35,8 @@ class SensorUpdate:
     devices: dict[str | None, SensorDeviceInfo]
     entity_descriptions: dict[DeviceKey, SensorDescription]
     entity_values: dict[DeviceKey, SensorValue]
+    binary_entity_descriptions: dict[DeviceKey, BinarySensorDescription]
+    binary_entity_values: dict[DeviceKey, BinarySensorValue]
 
 
 class SensorData:
@@ -42,17 +49,34 @@ class SensorData:
         self._device_id_info: dict[str | None, SensorDeviceInfo] = {}
         self._device_id_to_name: dict[str | None, str] = {}
         self._device_id_to_type: dict[str | None, str] = {}
-        self._descriptions: dict[DeviceKey, SensorDescription] = {}
-        self._descriptions_updates: dict[DeviceKey, SensorDescription] = {}
-        self._values: dict[DeviceKey, SensorValue] = {}
-        self._values_updates: dict[DeviceKey, SensorValue] = {}
+
+        # Sensors
+        self._sensor_descriptions: dict[DeviceKey, SensorDescription] = {}
+        self._sensor_descriptions_updates: dict[DeviceKey, SensorDescription] = {}
+        self._sensor_values: dict[DeviceKey, SensorValue] = {}
+        self._sensor_values_updates: dict[DeviceKey, SensorValue] = {}
+
+        # Binary Sensors
+        self._binary_sensor_descriptions: dict[DeviceKey, BinarySensorDescription] = {}
+        self._binary_sensor_descriptions_updates: dict[
+            DeviceKey, BinarySensorDescription
+        ] = {}
+        self._binary_sensor_values: dict[DeviceKey, BinarySensorValue] = {}
+        self._binary_sensor_values_updates: dict[DeviceKey, BinarySensorValue] = {}
 
     @property
     def descriptions(
         self,
     ) -> dict[DeviceKey, SensorDescription]:
-        """Return the data."""
-        return self._descriptions
+        """Return the sensor data."""
+        return self._sensor_descriptions
+
+    @property
+    def binary_descriptions(
+        self,
+    ) -> dict[DeviceKey, BinarySensorDescription]:
+        """Return the binary sensor data."""
+        return self._binary_sensor_descriptions
 
     @property
     def primary_device_id(self) -> str | None:
@@ -121,13 +145,40 @@ class SensorData:
         return self._finish_update()
 
     def _finish_update(self) -> SensorUpdate:
-        self._descriptions.update(self._descriptions_updates)
-        self._values.update(self._values_updates)
+        """Finish the update."""
+        self._sensor_descriptions.update(self._sensor_descriptions_updates)
+        self._sensor_values.update(self._sensor_values_updates)
+
+        self._binary_sensor_descriptions.update(
+            self._binary_sensor_descriptions_updates
+        )
+        self._binary_sensor_values.update(self._binary_sensor_values_updates)
+
         return SensorUpdate(
             title=self._title,
             devices=self._device_id_info,
-            entity_descriptions=self._descriptions_updates,
-            entity_values=self._values_updates,
+            entity_descriptions=self._sensor_descriptions_updates,
+            entity_values=self._sensor_values_updates,
+            binary_entity_descriptions=self._binary_sensor_descriptions_updates,
+            binary_entity_values=self._binary_sensor_values_updates,
+        )
+
+    def update_predefined_binary_sensor(
+        self,
+        device_class: BinarySensorDeviceClass,
+        native_value: bool | None,
+        key: str | None = None,
+        name: str | None = None,
+        device_id: str | None = None,
+    ) -> None:
+        """Update a binary sensor by type."""
+        assert device_class is not None  # nosec
+        self.update_binary_sensor(
+            key=key or device_class.value,
+            name=name,
+            native_value=native_value,
+            device_class=device_class,
+            device_id=device_id,
         )
 
     def update_predefined_sensor(
@@ -159,23 +210,43 @@ class SensorData:
             device_id
         )
 
+    def update_binary_sensor(
+        self,
+        key: str,
+        native_value: bool | None,
+        device_class: BinarySensorDeviceClass | None = None,
+        name: str | None = None,
+        device_id: str | None = None,
+    ) -> None:
+        """Update a sensor by type."""
+        device_key = DeviceKey(key, device_id)
+        self._binary_sensor_values_updates[device_key] = BinarySensorValue(
+            name=name or self._get_key_name(key, device_id),
+            device_key=device_key,
+            native_value=native_value,
+        )
+        self._binary_sensor_descriptions_updates[device_key] = BinarySensorDescription(
+            device_key=device_key,
+            device_class=device_class,
+        )
+
     def update_sensor(
         self,
         key: str,
         native_unit_of_measurement: Units | None,
         native_value: None | str | int | float | date | datetime | Decimal,
-        device_class: DeviceClass | None = None,
+        device_class: SensorDeviceClass | None = None,
         name: str | None = None,
         device_id: str | None = None,
     ) -> None:
         """Update a sensor."""
         device_key = DeviceKey(key, device_id)
-        self._values_updates[device_key] = SensorValue(
+        self._sensor_values_updates[device_key] = SensorValue(
             name=name or self._get_key_name(key, device_id),
             device_key=device_key,
             native_value=native_value,
         )
-        self._descriptions_updates[device_key] = SensorDescription(
+        self._sensor_descriptions_updates[device_key] = SensorDescription(
             device_key=device_key,
             native_unit_of_measurement=native_unit_of_measurement,
             device_class=device_class,
